@@ -4,6 +4,13 @@ from beta9.cli.extraclick import ClickCommonGroup
 from beta9.config import ConfigContext, get_settings, load_config, save_config
 
 
+def validate_token(ctx: click.Context, param: click.Parameter, value: str):
+    token = value.strip()
+    if not token or len(token) < 64:
+        raise click.BadParameter("A valid token is required", ctx=ctx, param=param)
+    return token
+
+
 @click.group(cls=ClickCommonGroup)
 def common(**_):
     pass
@@ -29,6 +36,7 @@ def common(**_):
     type=click.STRING,
     help="The token.",
     required=True,
+    callback=validate_token,
 )
 @click.argument(
     "name",
@@ -40,7 +48,7 @@ def configure(token: str, name: str):
     config_path = settings.config_path
     contexts = load_config(config_path)
 
-    if name in contexts and contexts[name].token:
+    if name in contexts and contexts[name].is_valid():
         text = f"Context '{name}' already exists. Overwrite?"
         if terminal.prompt(text=text, default="n").lower() in ["n", "no"]:
             return
